@@ -6,7 +6,7 @@ from libbiomedit.lib import classify
 
 
 class TestClassify(unittest.TestCase):
-    def test_classify(self):
+    def test_classify(self) -> None:
         self.assertEqual(classify.classify(Dict[str, str]), Dict)
         self.assertEqual(classify.classify(Tuple[int, ...]), Tuple)
         self.assertEqual(classify.classify(Optional[str]), Optional)
